==> constructorio-ui-quizzes-1.2.3.tgz: package/lib/mjs/components/CoverTypeQuestion/CoverTypeQuestion.js <==
import React, { useContext } from 'react';
import QuestionTitle from '../QuestionTitle/QuestionTitle';
import QuizContext from '../CioQuiz/context';
import QuestionDescription from '../QuestionDescription/QuestionDescription';
import { renderImages } from '../../utils';
import { QuestionTypes } from '../CioQuiz/actions';
import ControlBar from '../ControlBar/ControlBar';
export default function CoverTypeQuestion() {
    const { questionResponse, quizBackHandler, quizNextHandler, isFirstQuestion } = useContext(QuizContext);
    let question;
    if (questionResponse) {
        question = questionResponse.next_question;
    }
    const hasImage = question?.images?.primary_url;
    const onNextClick = () => {
        if (quizNextHandler) {
            quizNextHandler({
                type: QuestionTypes.Cover,
                payload: {
                    isLastQuestion: questionResponse?.is_last_question,
                },
            });
        }
    };
    if (question) {
        return (React.createElement("div", { className: `
        cio-container${hasImage ? '--with-image' : ''}
        cio-cover-question-container${hasImage ? '--with-image' : ''}
      ` },
            React.createElement("div", { className: 'cio-question-content' },
                React.createElement(QuestionTitle, { title: question?.title }),
                React.createElement(QuestionDescription, { description: question.description }),
                React.createElement(ControlBar, { nextButtonHandler: onNextClick, backButtonHandler: quizBackHandler, showBackButton: !isFirstQuestion, ctaButtonText: question?.cta_text })),
            hasImage ? renderImages(question.images, 'cio-question-image-container') : ''));
    }
    return null;
}

==> constructorio-ui-quizzes-1.3.1.tgz: package/lib/mjs/components/CoverTypeQuestion/CoverTypeQuestion.js <==
import React, { useContext } from 'react';
import QuestionTitle from '../QuestionTitle/QuestionTitle';
import QuizContext from '../CioQuiz/context';
import QuestionDescription from '../QuestionDescription/QuestionDescription';
import { renderImages } from '../../utils';
import ControlBar from '../ControlBar/ControlBar';
export default function CoverTypeQuestion() {
    const { state, previousQuestion, nextQuestion } = useContext(QuizContext);
    let question;
    if (state?.quiz.currentQuestion) {
        question = state?.quiz.currentQuestion.next_question;
    }
    const hasImage = question?.images?.primary_url;
    const onNextClick = () => {
        if (nextQuestion) {
            nextQuestion();
        }
    };
    if (question) {
        return (React.createElement("div", { className: `
        cio-container${hasImage ? '--with-image' : ''}
        cio-cover-question-container${hasImage ? '--with-image' : ''}
      ` },
            React.createElement("div", { className: 'cio-question-content' },
                React.createElement(QuestionTitle, { title: question?.title }),
                React.createElement(QuestionDescription, { description: question.description }),
                React.createElement(ControlBar, { nextButtonHandler: onNextClick, backButtonHandler: previousQuestion, showBackButton: !state?.quiz.isFirstQuestion, ctaButtonText: question?.cta_text })),
            hasImage ? renderImages(question.images, 'cio-question-image-container') : ''));
    }
    return null;
}
